@@ -14,16 +14,7 @@ def setup_logging(name=None, log_level=logging.INFO):
         datefmt = "%Y-%m-%d %H:%M:%S"
 
         # Suppress overly verbose output that isn't helpful from some libraries we depend on
-        for key in [
-            "requests",
-            "tensorboard",
-            "urllib3",
-            "aiohttp.access",
-            "uamqp",
-            "sqlalchemy",
-            "sqlalchemy.engine.base",
-            "matplotlib.font_manager",
-        ]:
+        for key in ["requests", "tensorboard", "urllib3", "aiohttp.access", "uamqp", "sqlalchemy", "sqlalchemy.engine.base", "matplotlib.font_manager"]:
             logging.getLogger(key).setLevel(logging.WARNING)
 
         # Enable debug logging for some insteresting libraries (for development)
@@ -32,20 +23,7 @@ def setup_logging(name=None, log_level=logging.INFO):
         try:
             from colorlog import ColoredFormatter
 
-            logging.getLogger().handlers[0].setFormatter(
-                ColoredFormatter(
-                    colorfmt,
-                    datefmt=datefmt,
-                    reset=True,
-                    log_colors={
-                        "DEBUG": "cyan",
-                        "INFO": "green",
-                        "WARNING": "yellow",
-                        "ERROR": "red",
-                        "CRITICAL": "red",
-                    },
-                )
-            )
+            logging.getLogger().handlers[0].setFormatter(ColoredFormatter(colorfmt, datefmt=datefmt, reset=True, log_colors={"DEBUG": "cyan", "INFO": "green", "WARNING": "yellow", "ERROR": "red", "CRITICAL": "red"}))
         except ImportError:
             # Ignore failures in loading color coded logs
             pass
@@ -57,4 +35,3 @@ def setup_logging(name=None, log_level=logging.INFO):
         name = inspect.stack()[1][1]
     logger = logging.getLogger(name)
     return logger
-
